@@ -17,39 +17,46 @@
 # limitations under the License.
 """Clone a Renku repo along with all Renku-specific initializations."""
 
+from pathlib import Path
+from typing import Any, Dict, Optional, Union
+
+from git.remote import RemoteProgress
+from pydantic import validate_arguments
+
 from renku.command.command_builder.command import Command
 from renku.domain_model.project_context import project_context
 
 
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def _project_clone(
-    url,
-    path=None,
-    install_githooks=True,
-    install_mergetool=True,
-    skip_smudge=True,
-    recursive=True,
-    depth=None,
-    progress=None,
-    config=None,
-    raise_git_except=False,
-    checkout_revision=None,
-    use_renku_credentials=False,
+    url: str,
+    path: Optional[Union[str, Path]] = None,
+    install_githooks: bool = True,
+    install_mergetool: bool = True,
+    skip_smudge: bool = True,
+    recursive: bool = True,
+    depth: Optional[int] = None,
+    progress: Optional[RemoteProgress] = None,
+    config: Optional[Dict[str, Any]] = None,
+    raise_git_except: bool = False,
+    checkout_revision: Optional[str] = None,
+    use_renku_credentials: bool = False,
 ):
     """Clone Renku project repo, install Git hooks and LFS.
 
     Args:
-        url: Git URL to clone.
-        path: Path to clone to (Default value = None).
-        install_githooks: Whether to install the pre-commit hook or not (Default value = True).
-        install_mergetool: Whether to install the renku metadata git mergetool or not (Default value = True).
-        skip_smudge: Whether to skip pulling files from LFS (Default value = True).
-        recursive: Recursively clone (Default value = True).
-        depth: Clone depth (commits from HEAD) (Default value = None).
-        progress: Git progress object (Default value = None).
-        config: Initial config (Default value = None).
-        raise_git_except: Whether to raise Git exceptions or not (Default value = False).
-        checkout_revision: Specific revision to check out (Default value = None).
-        use_renku_credentials: Whether to use credentials stored in renku (Default value = False).
+        url(str): Git URL to clone.
+        path(Optional[str]): Path to clone to (Default value = None).
+        install_githooks(bool): Whether to install the pre-commit hook or not (Default value = True).
+        install_mergetool(bool): Whether to install the renku metadata git mergetool or not (Default value = True).
+        skip_smudge(bool): Whether to skip pulling files from LFS (Default value = True).
+        recursive(bool): Recursively clone (Default value = True).
+        depth(Optional[int]): Clone depth (commits from HEAD) (Default value = None).
+        progress(Optional[RemoteProgress]): Git progress object (Default value = None).
+        config(Optional[Dict[str, Any]]): Initial config (Default value = None).
+        raise_git_except(bool): Whether to raise Git exceptions or not (Default value = False).
+        checkout_revision(Optional[str]): Specific revision to check out (Default value = None).
+        use_renku_credentials(bool): Whether to use credentials stored in renku (Default value = False).
 
     Returns:
         Tuple of cloned ``Repository`` and whether it's a Renku project or not.
