@@ -37,17 +37,25 @@ class ProjectSchema(JsonLDSchema):
 
     agent_version = StringList(schema.agent, load_default="pre-0.11.0")
     annotations = Nested(oa.hasTarget, AnnotationSchema, reverse=True, many=True)
-    automated_update = fields.Boolean(renku.automatedTemplateUpdate, load_default=True)
     creator = Nested(schema.creator, PersonSchema, load_default=None)
     date_created = DateTimeList(schema.dateCreated, load_default=None, format="iso", extra_formats=("%Y-%m-%d",))
     description = fields.String(schema.description, load_default=None)
     id = fields.Id(load_default=None)
-    immutable_template_files = fields.List(renku.immutableTemplateFiles, fields.String(), load_default=list())
+    immutable_template_files = fields.List(
+        renku.immutableTemplateFiles,
+        fields.String(),
+        load_default=list(),
+        attribute="template_metadata.immutable_template_files",
+    )
     name = fields.String(schema.name, load_default=None)
-    template_id = fields.String(renku.templateId, load_default=None)
-    template_metadata = fields.String(renku.templateMetadata, load_default=None)
-    template_ref = fields.String(renku.templateReference, load_default=None)
-    template_source = fields.String(renku.templateSource, load_default=None)
-    template_version = fields.String(renku.templateVersion, load_default=None)
+    template_id = fields.String(renku.templateId, load_default=None, attribute="template_metadata.template_id")
+    template_metadata = fields.String(renku.templateMetadata, load_default=None, attribute="template_metadata.metadata")
+    template_ref = fields.String(renku.templateReference, load_default=None, attribute="template_metadata.template_ref")
+    template_source = fields.String(
+        renku.templateSource, load_default=None, attribute="template_metadata.template_source"
+    )
+    template_version = fields.String(
+        renku.templateVersion, load_default=None, attribute="template_metadata.template_version"
+    )
     version = StringList(schema.schemaVersion, load_default="1")
     keywords = fields.List(schema.keywords, fields.String(), load_default=None)
