@@ -16,6 +16,3 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Renku core."""
-import logging
-
-logging.getLogger("filelock").setLevel(logging.ERROR)
