@@ -24,6 +24,7 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union, cast
 
 import patoolib
+from pydantic import validate_arguments
 
 from renku.command.command_builder.command import inject
 from renku.command.view_model.dataset import DatasetFileViewModel, DatasetViewModel
@@ -37,7 +38,6 @@ from renku.core.dataset.providers.s3 import S3Credentials
 from renku.core.dataset.request_model import ImageRequestModel
 from renku.core.dataset.tag import get_dataset_by_tag, prompt_access_token, prompt_tag_selection
 from renku.core.interface.dataset_gateway import IDatasetGateway
-from renku.core.interface.storage import IStorageFactory
 from renku.core.storage import check_external_storage, pull_paths_from_storage, track_paths_in_storage
 from renku.core.util import communication
 from renku.core.util.datetime8601 import local_now
@@ -69,6 +69,7 @@ if TYPE_CHECKING:
     from renku.infrastructure.repository import Repository
 
 
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def search_datasets(name: str) -> List[str]:
     """Get all the datasets whose name starts with the given string.
 
@@ -89,7 +90,7 @@ def list_datasets():
 
     for dataset in datasets_provenance.datasets:
         tags = datasets_provenance.get_all_tags(dataset)
-        dataset = DynamicProxy(dataset)
+        dataset = cast(Dataset, DynamicProxy(dataset))
         dataset.tags = tags
         dataset.tags_csv = ",".join(tag.name for tag in tags)
         dataset.datadir_path = str(dataset.get_datadir())
@@ -98,6 +99,7 @@ def list_datasets():
     return list(datasets)
 
 
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def create_dataset(
     name: str,
     title: Optional[str] = None,
@@ -187,6 +189,7 @@ def create_dataset(
     return dataset
 
 
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def edit_dataset(
     name: str,
     title: Optional[Union[str, NoValueType]],
@@ -266,21 +269,22 @@ def edit_dataset(
     return updated
 
 
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def list_dataset_files(
-    datasets: List[str] = None,
+    datasets: Optional[List[str]] = None,
     tag: Optional[str] = None,
-    creators=None,
-    include=None,
-    exclude=None,
+    creators: Optional[Union[str, List[str], Tuple[str]]] = None,
+    include: Optional[List[str]] = None,
+    exclude: Optional[List[str]] = None,
 ):
     """List dataset files.
 
     Args:
-        datasets(List[str]): Datasets to list files for (Default value = None).
+        datasets(Optional[List[str]]): Datasets to list files for (Default value = None).
         tag(str): Tag to filter by (Default value = None).
-        creators: Creators to filter by (Default value = None).
-        include: Include filters for file paths (Default value = None).
-        exclude: Exclude filters for file paths (Default value = None).
+        creators(Optional[Union[str, List[str], Tuple[str]]]): Creators to filter by (Default value = None).
+        include(Optional[List[str]]): Include filters for file paths (Default value = None).
+        exclude(Optional[List[str]]): Exclude filters for file paths (Default value = None).
 
     Returns:
         List[DynamicProxy]: Filtered dataset files.
@@ -306,14 +310,15 @@ def list_dataset_files(
     return records
 
 
-def file_unlink(name, include, exclude, yes=False):
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
+def file_unlink(name: str, include: Optional[List[str]], exclude: Optional[List[str]], yes: bool = False):
     """Remove matching files from a dataset.
 
     Args:
-        name: Dataset name.
-        include: Include filter for files.
-        exclude: Exclude filter for files.
-        yes: Whether to skip user confirmation or not (Default value = False).
+        name(str): Dataset name.
+        include(Optional[List[str]]): Include filter for files.
+        exclude(Optional[List[str]]): Exclude filter for files.
+        yes(bool): Whether to skip user confirmation or not (Default value = False).
 
     Returns:
         List[DynamicProxy]: List of files that were removed.
@@ -371,24 +376,26 @@ def file_unlink(name, include, exclude, yes=False):
     return records
 
 
-def remove_dataset(name):
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
+def remove_dataset(name: str):
     """Delete a dataset.
 
     Args:
-        name: Name of dataset to delete.
+        name(str): Name of dataset to delete.
     """
     datasets_provenance = DatasetsProvenance()
     dataset = datasets_provenance.get_by_name(name=name, strict=True)
     datasets_provenance.remove(dataset=dataset)
 
 
-def export_dataset(name, provider_name, tag, **kwargs):
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
+def export_dataset(name: str, provider_name: str, tag: Optional[str], **kwargs):
     """Export data to 3rd party provider.
 
     Args:
-        name: Name of dataset to export.
-        provider_name: Provider to use for export.
-        tag: Dataset tag from which to export.
+        name(str): Name of dataset to export.
+        provider_name(str): Provider to use for export.
+        tag(str): Dataset tag from which to export.
     """
     datasets_provenance = DatasetsProvenance()
 
@@ -399,7 +406,7 @@ def export_dataset(name, provider_name, tag, **kwargs):
 
     dataset: Optional[Dataset] = datasets_provenance.get_by_name(name, strict=True, immutable=True)
 
-    provider = ProviderFactory.from_name(provider_name)
+    provider = ProviderFactory.get_export_provider(provider_name=provider_name)
 
     selected_tag = None
     tags = datasets_provenance.get_all_tags(dataset)  # type: ignore
@@ -444,9 +451,10 @@ def export_dataset(name, provider_name, tag, **kwargs):
     communication.echo(f"Exported to: {destination}")
 
 
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def import_dataset(
     uri: str,
-    name: str = "",
+    name: Optional[str] = "",
     extract: bool = False,
     yes: bool = False,
     datadir: Optional[Path] = None,
@@ -558,6 +566,7 @@ def import_dataset(
 
 
 @inject.autoparams()
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def update_datasets(
     names: List[str],
     creators: Optional[str],
@@ -571,6 +580,7 @@ def update_datasets(
     check_data_directory: bool,
     update_all: bool,
     dry_run: bool,
+    plain: bool,
     dataset_gateway: IDatasetGateway,
 ) -> Tuple[List[DatasetViewModel], List[DatasetFileViewModel]]:
     """Update dataset files.
@@ -588,6 +598,7 @@ def update_datasets(
         check_data_directory(bool): Whether to check the dataset's data directory for new files.
         update_all(bool): Whether to update all datasets.
         dry_run(bool): Whether to return a preview of what would be updated.
+        plain(bool): Whether plain output should be produced.
         dataset_gateway(IDatasetGateway): Injected dataset gateway.
     """
     from renku.core.dataset.providers.renku import RenkuProvider
@@ -681,7 +692,7 @@ def update_datasets(
     )
 
     if not records:
-        if must_match_records:
+        if must_match_records and not plain:
             raise errors.ParameterError("No files matched the criteria.")
         return imported_dataset_updates_view_models, []
 
@@ -752,6 +763,7 @@ def update_datasets(
     return imported_dataset_updates_view_models, dataset_files_view_models
 
 
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def show_dataset(name: str, tag: Optional[str] = None):
     """Show detailed dataset information.
 
@@ -879,11 +891,7 @@ def update_dataset_custom_metadata(
 
 
 @inject.autoparams("dataset_gateway")
-def move_files(
-    dataset_gateway: IDatasetGateway,
-    files: Dict[Path, Path],
-    to_dataset_name: Optional[str] = None,
-):
+def move_files(dataset_gateway: IDatasetGateway, files: Dict[Path, Path], to_dataset_name: Optional[str] = None):
     """Move files and their metadata from one or more datasets to a target dataset.
 
     Args:
@@ -1222,13 +1230,12 @@ def filter_dataset_files(
     return sorted(records, key=lambda r: r.date_added)
 
 
-@inject.autoparams("storage_factory")
-def pull_external_data(name: str, storage_factory: IStorageFactory, location: Optional[Path] = None) -> None:
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
+def pull_external_data(name: str, location: Optional[Path] = None) -> None:
     """Pull/copy data for an external storage to a dataset's data directory or a specified location.
 
     Args:
         name(str): Name of the dataset
-        storage_factory(IStorageFactory):Injected storage factory.
         location(Optional[Path]): A directory to copy data to (Default value = None).
     """
     datasets_provenance = DatasetsProvenance()
@@ -1256,11 +1263,8 @@ def pull_external_data(name: str, storage_factory: IStorageFactory, location: Op
             create_symlinks = False
 
     provider = ProviderFactory.get_pull_provider(uri=dataset.storage)
+    storage = provider.get_storage()
 
-    credentials = S3Credentials(provider)
-    prompt_for_credentials(credentials)
-
-    storage = storage_factory.get_storage(provider=provider, credentials=credentials)
     updated_files = []
 
     for file in dataset.files:
@@ -1268,16 +1272,16 @@ def pull_external_data(name: str, storage_factory: IStorageFactory, location: Op
         path.parent.mkdir(parents=True, exist_ok=True)
         # NOTE: Don't check if destination exists. ``IStorage.copy`` won't copy a file if it exists and is not modified.
 
-        if not file.source:
+        if not file.based_on:
             raise errors.DatasetImportError(f"Dataset file doesn't have a URI: {file.entity.path}")
 
         with communication.busy(f"Copying {file.entity.path} ..."):
-            storage.copy(file.source, path)
+            storage.download(file.based_on.url, path)
 
             # NOTE: Make files read-only since we don't support pushing data to the remote storage
             os.chmod(path, 0o400)
 
-            if file.based_on and not file.based_on.checksum:
+            if not file.based_on.checksum:
                 md5_hash = hash_file(path, hash_type="md5") or ""
                 file.based_on = RemoteEntity(checksum=md5_hash, url=file.based_on.url, path=file.based_on.path)
 
@@ -1313,20 +1317,14 @@ def read_dataset_data_location(dataset: Dataset) -> Optional[str]:
     return get_value(section="dataset-locations", key=dataset.name, config_filter=ConfigFilter.LOCAL_ONLY)
 
 
-@inject.autoparams("storage_factory")
-def mount_external_storage(
-    name: str,
-    existing: Optional[Path],
-    yes: bool,
-    storage_factory: IStorageFactory,
-) -> None:
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
+def mount_external_storage(name: str, existing: Optional[Path], yes: bool) -> None:
     """Mount an external storage to a dataset's data directory.
 
     Args:
         name(str): Name of the dataset
         existing(Optional[Path]): An existing mount point to use instead of actually mounting the external storage.
         yes(bool): Don't prompt when removing non-empty dataset's data directory.
-        storage_factory(IStorageFactory): Injected storage factory.
     """
     dataset, datadir = _get_dataset_with_external_storage(name=name)
 
@@ -1350,12 +1348,13 @@ def mount_external_storage(
     provider = ProviderFactory.get_mount_provider(uri=dataset.storage)
     credentials = S3Credentials(provider)
     prompt_for_credentials(credentials)
+    storage = provider.get_storage(credentials=credentials)
 
-    storage = storage_factory.get_storage(provider=provider, credentials=credentials)
     with communication.busy(f"Mounting {provider.uri}"):
         storage.mount(datadir)
 
 
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def unmount_external_storage(name: str) -> None:
     """Mount an external storage to a dataset's data directory.
 
