@@ -18,7 +18,7 @@
 """Dataverse API integration."""
 
 import json
-import pathlib
+import posixpath
 import re
 import urllib
 from pathlib import Path
@@ -28,7 +28,13 @@ from urllib import parse as urlparse
 
 from renku.core import errors
 from renku.core.config import get_value, set_value
-from renku.core.dataset.providers.api import ExporterApi, ProviderApi, ProviderPriority
+from renku.core.dataset.providers.api import (
+    ExporterApi,
+    ExportProviderInterface,
+    ImportProviderInterface,
+    ProviderApi,
+    ProviderPriority,
+)
 from renku.core.dataset.providers.dataverse_metadata_templates import (
     AUTHOR_METADATA_TEMPLATE,
     CONTACT_METADATA_TEMPLATE,
@@ -71,7 +77,7 @@ DATAVERSE_SUBJECTS = [
 ]
 
 
-class DataverseProvider(ProviderApi):
+class DataverseProvider(ProviderApi, ExportProviderInterface, ImportProviderInterface):
     """Dataverse API provider."""
 
     priority = ProviderPriority.HIGH
@@ -95,16 +101,6 @@ class DataverseProvider(ProviderApi):
 
         return is_dataverse_uri or is_dataverse_doi
 
-    @staticmethod
-    def supports_export():
-        """Whether this provider supports dataset export."""
-        return True
-
-    @staticmethod
-    def supports_import():
-        """Whether this provider supports dataset import."""
-        return True
-
     @staticmethod
     def get_export_parameters() -> List["ProviderParameter"]:
         """Returns parameters that can be set for export."""
@@ -477,10 +473,10 @@ class _DataverseDeposition:
     def _make_url(self, api_path, **query_params):
         """Create URL for creating a dataset."""
         url_parts = urlparse.urlparse(self.server_url)
-        path = pathlib.posixpath.join(DATAVERSE_API_PATH, api_path)
+        path = posixpath.join(DATAVERSE_API_PATH, api_path)
 
-        query_params = urllib.parse.urlencode(query_params)
-        url_parts = url_parts._replace(path=path, query=query_params)
+        query_params_str = urllib.parse.urlencode(query_params)
+        url_parts = url_parts._replace(path=path, query=query_params_str)
         return urllib.parse.urlunparse(url_parts)
 
     def _post(self, url, json=None, data=None, files=None):
@@ -519,7 +515,7 @@ def check_dataverse_uri(url):
     from renku.core.util import requests
 
     url_parts = list(urlparse.urlparse(url))
-    url_parts[2] = pathlib.posixpath.join(DATAVERSE_API_PATH, DATAVERSE_VERSION_API)
+    url_parts[2] = posixpath.join(DATAVERSE_API_PATH, DATAVERSE_VERSION_API)
 
     url_parts[3:6] = [""] * 3
     version_url = urlparse.urlunparse(url_parts)
@@ -555,7 +551,7 @@ def check_dataverse_doi(doi):
 def make_records_url(record_id, base_url):
     """Create URL to access record by ID."""
     url_parts = list(urlparse.urlparse(base_url))
-    url_parts[2] = pathlib.posixpath.join(DATAVERSE_API_PATH, DATAVERSE_METADATA_API)
+    url_parts[2] = posixpath.join(DATAVERSE_API_PATH, DATAVERSE_METADATA_API)
     args_dict = {"exporter": DATAVERSE_EXPORTER, "persistentId": record_id}
     url_parts[4] = urllib.parse.urlencode(args_dict)
     return urllib.parse.urlunparse(url_parts)
@@ -564,7 +560,7 @@ def make_records_url(record_id, base_url):
 def make_versions_url(record_id, base_url):
     """Create URL to access the versions of a record."""
     url_parts = list(urlparse.urlparse(base_url))
-    url_parts[2] = pathlib.posixpath.join(DATAVERSE_API_PATH, DATAVERSE_VERSIONS_API)
+    url_parts[2] = posixpath.join(DATAVERSE_API_PATH, DATAVERSE_VERSIONS_API)
     args_dict = {"exporter": DATAVERSE_EXPORTER, "persistentId": record_id}
     url_parts[4] = urllib.parse.urlencode(args_dict)
     return urllib.parse.urlunparse(url_parts)
@@ -573,7 +569,7 @@ def make_versions_url(record_id, base_url):
 def make_file_url(file_id, base_url):
     """Create URL to access record by ID."""
     url_parts = list(urlparse.urlparse(base_url))
-    url_parts[2] = pathlib.posixpath.join(DATAVERSE_API_PATH, DATAVERSE_FILE_API)
+    url_parts[2] = posixpath.join(DATAVERSE_API_PATH, DATAVERSE_FILE_API)
     args_dict = {"persistentId": file_id}
     url_parts[4] = urllib.parse.urlencode(args_dict)
     return urllib.parse.urlunparse(url_parts)
