@@ -27,7 +27,7 @@ from typing import TYPE_CHECKING, Any, Dict, List, Optional
 from renku.command.login import read_renku_token
 from renku.core import errors
 from renku.core.dataset.datasets_provenance import DatasetsProvenance
-from renku.core.dataset.providers.api import ImporterApi, ProviderApi, ProviderPriority
+from renku.core.dataset.providers.api import ImporterApi, ImportProviderInterface, ProviderApi, ProviderPriority
 from renku.core.storage import pull_paths_from_storage
 from renku.core.util import communication
 from renku.core.util.git import clone_renku_repository, get_cache_directory_for_repository, get_file_size
@@ -40,7 +40,7 @@ if TYPE_CHECKING:
     from renku.domain_model.dataset import Dataset
 
 
-class RenkuProvider(ProviderApi):
+class RenkuProvider(ProviderApi, ImportProviderInterface):
     """Renku API provider."""
 
     priority = ProviderPriority.HIGH
@@ -50,9 +50,9 @@ class RenkuProvider(ProviderApi):
         super().__init__(uri=uri)
 
         self._accept = "application/json"
-        self._authorization_header = None
+        self._authorization_header: Optional[Dict[str, str]] = None
         self._gitlab_token: Optional[str] = None
-        self._renku_token = None
+        self._renku_token: Optional[str] = None
         self._tag: Optional[str] = None
 
     @staticmethod
@@ -66,11 +66,6 @@ class RenkuProvider(ProviderApi):
         _, dataset_id = RenkuProvider._extract_project_and_dataset_ids(parsed_url)
         return dataset_id is not None
 
-    @staticmethod
-    def supports_import():
-        """Whether this provider supports dataset import."""
-        return True
-
     @staticmethod
     def get_import_parameters() -> List["ProviderParameter"]:
         """Returns parameters that can be set for import."""
@@ -251,7 +246,7 @@ class RenkuImporter(ImporterApi):
 
         self._project_url = None
         self._remote_repository = None
-        self._remote_path = None
+        self._remote_path: Optional[Path] = None
 
     def fetch_provider_dataset(self) -> "ProviderDataset":
         """Return encapsulated dataset instance."""
@@ -327,7 +322,19 @@ class RenkuImporter(ImporterApi):
         results: List["DatasetAddMetadata"] = []
         new_files: Dict[Path, List[str]] = defaultdict(list)
 
-        if checksums is None:
+        if self.provider_dataset.storage:  # NOTE: Dataset with a backend storage
+            results = [
+                DatasetAddMetadata(
+                    entity_path=Path(f.path),
+                    url=url,
+                    based_on=RemoteEntity(checksum=f.checksum, path=f.path, url=url),
+                    action=DatasetAddAction.METADATA_ONLY,
+                    source=remote_repository.path / f.path,
+                    destination=destination / f.path,
+                )
+                for f in self.provider_dataset_files
+            ]
+        elif checksums is None:
             with project_context.with_path(remote_repository.path):
                 pull_paths_from_storage(
                     project_context.repository, *(remote_repository.path / p for p in sources)  # type: ignore
@@ -380,7 +387,6 @@ class RenkuImporter(ImporterApi):
 
     def copy_extra_metadata(self, new_dataset: "Dataset") -> None:
         """Copy provider specific metadata once the dataset is created."""
-
         if not self.provider_dataset.images:
             return
 
@@ -388,6 +394,8 @@ class RenkuImporter(ImporterApi):
             if image.is_absolute:
                 continue
 
+            assert isinstance(self._remote_path, Path)  # TODO: Replace with proper typing
+
             remote_image_path = self._remote_path / image.content_url
             local_image_path = project_context.path / image.content_url
             local_image_path.parent.mkdir(exist_ok=True, parents=True)
@@ -434,6 +442,8 @@ class RenkuImporter(ImporterApi):
     @property
     def datadir_exists(self):
         """Whether the dataset data directory exists (might be missing in git if empty)."""
+        if self._remote_path is None:
+            raise errors.DatasetImportError("Dataset not fetched.")
         return (self._remote_path / self.provider_dataset.get_datadir()).exists()
 
     def _fetch_dataset(self):
