@@ -19,14 +19,20 @@
 
 import json
 import os
-import pathlib
+import posixpath
 import urllib
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Dict, List, Optional
 from urllib.parse import urlparse
 
 from renku.core import errors
-from renku.core.dataset.providers.api import ExporterApi, ProviderApi, ProviderPriority
+from renku.core.dataset.providers.api import (
+    ExporterApi,
+    ExportProviderInterface,
+    ImportProviderInterface,
+    ProviderApi,
+    ProviderPriority,
+)
 from renku.core.dataset.providers.repository import RepositoryImporter, make_request
 from renku.core.util import communication
 from renku.core.util.doi import is_doi
@@ -52,7 +58,7 @@ ZENODO_FILES_URL = "depositions/{0}/files"
 ZENODO_NEW_DEPOSIT_URL = "depositions"
 
 
-class ZenodoProvider(ProviderApi):
+class ZenodoProvider(ProviderApi, ExportProviderInterface, ImportProviderInterface):
     """Zenodo registry API provider."""
 
     priority = ProviderPriority.HIGH
@@ -72,16 +78,6 @@ class ZenodoProvider(ProviderApi):
 
         return False
 
-    @staticmethod
-    def supports_export():
-        """Whether this provider supports dataset export."""
-        return True
-
-    @staticmethod
-    def supports_import():
-        """Whether this provider supports dataset import."""
-        return True
-
     @staticmethod
     def get_record_id(uri):
         """Extract record id from URI."""
@@ -121,7 +117,7 @@ class ZenodoImporter(RepositoryImporter):
     def __init__(self, *, uri: str, original_uri, json: Dict[str, Any]):
         super().__init__(uri=uri, original_uri=original_uri)
 
-        self._jsonld = None
+        self._jsonld: Optional[dict] = None
         self._json = json
 
         metadata = self._json.pop("metadata", {})
@@ -152,7 +148,7 @@ class ZenodoImporter(RepositoryImporter):
         response = _make_request(self._uri, accept="application/ld+json")
         self._jsonld = response.json()
 
-        if "image" in self._jsonld and isinstance(self._jsonld["image"], str):
+        if self._jsonld is not None and "image" in self._jsonld and isinstance(self._jsonld["image"], str):
             self._jsonld["image"] = {
                 "@id": self._jsonld["image"],
                 "@type": "ImageObject",
@@ -407,7 +403,7 @@ class ZenodoDeposition:
         """Returns publish URL."""
         url = urllib.parse.urljoin(
             self.exporter.zenodo_url,
-            pathlib.posixpath.join(ZENODO_API_PATH, ZENODO_DEPOSIT_PATH, ZENODO_PUBLISH_ACTION_PATH.format(self.id)),
+            posixpath.join(ZENODO_API_PATH, ZENODO_DEPOSIT_PATH, ZENODO_PUBLISH_ACTION_PATH.format(self.id)),
         )
 
         return url
@@ -417,7 +413,7 @@ class ZenodoDeposition:
         """Return URL for attaching metadata."""
         url = urllib.parse.urljoin(
             self.exporter.zenodo_url,
-            pathlib.posixpath.join(ZENODO_API_PATH, ZENODO_DEPOSIT_PATH, ZENODO_METADATA_URL.format(self.id)),
+            posixpath.join(ZENODO_API_PATH, ZENODO_DEPOSIT_PATH, ZENODO_METADATA_URL.format(self.id)),
         )
         return url
 
@@ -426,7 +422,7 @@ class ZenodoDeposition:
         """Return URL for uploading file."""
         url = urllib.parse.urljoin(
             self.exporter.zenodo_url,
-            pathlib.posixpath.join(ZENODO_API_PATH, ZENODO_DEPOSIT_PATH, ZENODO_FILES_URL.format(self.id)),
+            posixpath.join(ZENODO_API_PATH, ZENODO_DEPOSIT_PATH, ZENODO_FILES_URL.format(self.id)),
         )
         return url
 
@@ -435,20 +431,20 @@ class ZenodoDeposition:
         """Return URL for creating new deposit."""
         url = urllib.parse.urljoin(
             self.exporter.zenodo_url,
-            pathlib.posixpath.join(ZENODO_API_PATH, ZENODO_DEPOSIT_PATH, ZENODO_NEW_DEPOSIT_URL),
+            posixpath.join(ZENODO_API_PATH, ZENODO_DEPOSIT_PATH, ZENODO_NEW_DEPOSIT_URL),
         )
         return url
 
     @property
     def published_at(self):
         """Return published at URL."""
-        url = urllib.parse.urljoin(self.exporter.zenodo_url, pathlib.posixpath.join(ZENODO_PUBLISH_PATH, str(self.id)))
+        url = urllib.parse.urljoin(self.exporter.zenodo_url, posixpath.join(ZENODO_PUBLISH_PATH, str(self.id)))
         return url
 
     @property
     def deposit_at(self):
         """Return deposit at URL."""
-        url = urllib.parse.urljoin(self.exporter.zenodo_url, pathlib.posixpath.join(ZENODO_DEPOSIT_PATH, str(self.id)))
+        url = urllib.parse.urljoin(self.exporter.zenodo_url, posixpath.join(ZENODO_DEPOSIT_PATH, str(self.id)))
         return url
 
     def new_deposition(self):
@@ -552,4 +548,4 @@ def make_records_url(record_id):
     Returns:
         str: Full URL for the record.
     """
-    return urllib.parse.urljoin(ZENODO_BASE_URL, pathlib.posixpath.join(ZENODO_API_PATH, "records", record_id))
+    return urllib.parse.urljoin(ZENODO_BASE_URL, posixpath.join(ZENODO_API_PATH, "records", record_id))
