@@ -18,9 +18,12 @@
 """Plan management."""
 
 import itertools
-from datetime import datetime, timedelta
+import os
+from datetime import timedelta
 from pathlib import Path
-from typing import Dict, Generator, List, Optional, Set, Tuple, Union, cast, overload
+from typing import Any, Dict, Generator, List, Optional, Set, Tuple, Union, cast, overload
+
+from pydantic import validate_arguments
 
 from renku.command.command_builder import inject
 from renku.command.format.workflow import WORKFLOW_FORMATS
@@ -29,12 +32,12 @@ from renku.core import errors
 from renku.core.interface.activity_gateway import IActivityGateway
 from renku.core.interface.plan_gateway import IPlanGateway
 from renku.core.interface.project_gateway import IProjectGateway
+from renku.core.plugin.workflow_file_parser import read_workflow_file
 from renku.core.util import communication
-from renku.core.util.datetime8601 import local_now
 from renku.core.util.git import get_git_user
-from renku.core.util.os import are_paths_related, get_relative_paths, safe_read_yaml
+from renku.core.util.os import are_paths_related, get_relative_paths
 from renku.core.util.util import NO_VALUE, NoValueType
-from renku.core.workflow.concrete_execution_graph import ExecutionGraph
+from renku.core.workflow.model.concrete_execution_graph import ExecutionGraph
 from renku.core.workflow.value_resolution import CompositePlanValueResolver, ValueResolver
 from renku.domain_model.project_context import project_context
 from renku.domain_model.provenance.activity import Activity
@@ -45,6 +48,36 @@ from renku.domain_model.workflow.plan import AbstractPlan, Plan
 from renku.infrastructure.immutable import DynamicProxy
 
 
+@inject.autoparams("plan_gateway")
+def get_plan(
+    plan_gateway: IPlanGateway, name_or_id_or_path: Optional[str] = None, workflow_file: Optional[str] = None
+) -> Union[AbstractPlan, str]:
+    """Return the latest version of a given plan in its derivative chain."""
+    plan = None
+
+    # NOTE: At first look for a plan with the given name or ID. If not found, look for a workflow file with that name.
+
+    if name_or_id_or_path:
+        try:
+            wf = plan_gateway.get_by_name_or_id(name_or_id_or_path)
+        except errors.WorkflowNotFoundError:
+            plan = None
+        else:
+            plan = None if is_plan_removed(wf) else wf
+    elif not workflow_file:
+        raise errors.ParameterError("Either 'name_or_id_or_path' or 'workflow_file' must be passed")
+
+    if plan:
+        return plan
+
+    path = cast(str, name_or_id_or_path or workflow_file)
+
+    if not os.path.exists(path):
+        raise errors.WorkflowNotFoundError(path)
+
+    return path
+
+
 @overload
 def get_latest_plan(plan: None = ..., plan_gateway: IPlanGateway = ...) -> None:  # noqa: D103
     ...
@@ -55,7 +88,7 @@ def get_latest_plan(plan: AbstractPlan, plan_gateway: IPlanGateway = ...) -> Abs
     ...
 
 
-@inject.autoparams()
+@inject.autoparams("plan_gateway")
 def get_latest_plan(
     plan: Optional[AbstractPlan], plan_gateway: IPlanGateway
 ) -> Union[Optional[AbstractPlan], AbstractPlan]:
@@ -89,6 +122,7 @@ def get_derivative_chain(
 
 
 @inject.autoparams()
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def search_workflows(name: str, plan_gateway: IPlanGateway) -> List[str]:
     """Get all the workflows whose Plan.name start with the given name.
 
@@ -103,7 +137,8 @@ def search_workflows(name: str, plan_gateway: IPlanGateway) -> List[str]:
 
 
 @inject.autoparams()
-def list_workflows(plan_gateway: IPlanGateway, format: str, columns: List[str]):
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
+def list_workflows(plan_gateway: IPlanGateway, format: str, columns: str):
     """List or manage workflows with subcommands.
 
     Args:
@@ -127,65 +162,68 @@ def list_workflows(plan_gateway: IPlanGateway, format: str, columns: List[str]):
     return WORKFLOW_FORMATS[format](list(map(lambda x: plan_view(x), workflows.values())), columns=columns)
 
 
-@inject.autoparams("plan_gateway", "activity_gateway")
-def show_workflow(
-    name_or_id: str, plan_gateway: IPlanGateway, activity_gateway: IActivityGateway, with_metadata: bool = False
-):
+@inject.autoparams("activity_gateway")
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
+def show_workflow(name_or_id_or_path: str, activity_gateway: IActivityGateway, with_metadata: bool = False):
     """Show the details of a workflow.
 
     Args:
-        name_or_id(str): Name or id of the Plan to show.
-        plan_gateway(IPlanGateway): The injected Plan gateway.
+        name_or_id_or_path(str): Name or id of the Plan to show or path to a workflow file.
         activity_gateway(IActivityGateway): The injected Activity gateway.
         with_metadata(bool): Whether to get additional calculated metadata for the plan.
     Returns:
         Details of the Plan.
     """
     from renku.command.view_model.plan import plan_view
+    from renku.command.view_model.workflow_file import WorkflowFileViewModel
 
-    workflow = cast(Union[Plan, CompositePlan], plan_gateway.get_by_name_or_id(name_or_id))
+    plan = get_plan(name_or_id_or_path=name_or_id_or_path)
 
-    if is_plan_removed(workflow):
-        raise errors.WorkflowNotFoundError(name_or_id)
+    if isinstance(plan, str):  # A workflow file
+        workflow_file = read_workflow_file(path=plan)
+        return WorkflowFileViewModel.from_workflow_file(workflow_file)
+    else:
+        workflow = plan
 
-    if with_metadata:
-        activities = activity_gateway.get_all_activities()
-        activity_map = _reverse_activity_plan_map(activities)
-        plan_chain = list(get_derivative_chain(workflow))
-        relevant_activities = [a for p in plan_chain for a in activity_map.get(p.id, [])]
-        touches_files_cache: Dict[str, bool] = {}
-        duration_cache: Dict[str, Optional[timedelta]] = {}
-        touches_existing_files = _check_workflow_touches_existing_files(workflow, touches_files_cache, activity_map)
+        if with_metadata:
+            activities = activity_gateway.get_all_activities()
+            activity_map = _reverse_activity_plan_map(activities)
+            plan_chain = list(get_derivative_chain(workflow))
+            relevant_activities = [a for p in plan_chain for a in activity_map.get(p.id, [])]
+            touches_files_cache: Dict[str, bool] = {}
+            duration_cache: Dict[str, Optional[timedelta]] = {}
+            touches_existing_files = _check_workflow_touches_existing_files(workflow, touches_files_cache, activity_map)
 
-        if isinstance(workflow, Plan):
+            if isinstance(workflow, Plan):
 
-            num_executions = 0
-            last_execution = None
+                num_executions = 0
+                last_execution = None
 
-            for activity in relevant_activities:
-                num_executions += 1
+                for activity in relevant_activities:
+                    num_executions += 1
 
-                if not last_execution or last_execution < activity.ended_at_time:
-                    last_execution = activity.ended_at_time
+                    if not last_execution or last_execution < activity.ended_at_time:
+                        last_execution = activity.ended_at_time
 
-            workflow = cast(Plan, DynamicProxy(workflow))
-            workflow.number_of_executions = num_executions
-            workflow.last_executed = last_execution
-            workflow.touches_existing_files = touches_existing_files
-            workflow.latest = plan_chain[0].id
-            workflow.duration = _get_plan_duration(workflow, duration_cache, activity_map)
-        else:
-            workflow = cast(CompositePlan, DynamicProxy(workflow))
-            workflow.touches_existing_files = touches_existing_files
-            workflow.latest = plan_chain[0].id
-            workflow.duration = _get_plan_duration(workflow, duration_cache, activity_map)
-            workflow.newest_plans = [get_latest_plan(p) for p in workflow.plans]
+                workflow = cast(Plan, DynamicProxy(workflow))
+                workflow.number_of_executions = num_executions
+                workflow.last_executed = last_execution
+                workflow.touches_existing_files = touches_existing_files
+                workflow.latest = plan_chain[0].id
+                workflow.duration = _get_plan_duration(workflow, duration_cache, activity_map)
+            else:
+                workflow = cast(CompositePlan, DynamicProxy(workflow))
+                workflow.touches_existing_files = touches_existing_files
+                workflow.latest = plan_chain[0].id
+                workflow.duration = _get_plan_duration(workflow, duration_cache, activity_map)
+                workflow.newest_plans = [get_latest_plan(p) for p in workflow.plans]
 
-    return plan_view(cast(AbstractPlan, workflow), latest=with_metadata)
+        return plan_view(cast(AbstractPlan, workflow), latest=with_metadata)
 
 
 @inject.autoparams("plan_gateway")
-def remove_plan(name_or_id: str, force: bool, plan_gateway: IPlanGateway, when: datetime = local_now()):
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
+def remove_plan(name_or_id: str, force: bool, plan_gateway: IPlanGateway):
     """Remove the workflow by its name or id.
 
     Args:
@@ -224,12 +262,13 @@ def remove_plan(name_or_id: str, force: bool, plan_gateway: IPlanGateway, when:
         communication.confirm(prompt_text, abort=True, warning=True)
 
     derived_plan = latest_version.derive()
-    derived_plan.delete(when=when)
+    derived_plan.delete()
 
     plan_gateway.add(derived_plan)
 
 
 @inject.autoparams()
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def edit_workflow(
     name: str,
     new_name: Optional[str],
@@ -338,21 +377,22 @@ def edit_workflow(
 
 
 @inject.autoparams()
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def compose_workflow(
     name: str,
-    description: str,
-    mappings: List[str],
-    defaults: List[str],
-    links: List[str],
-    param_descriptions: List[str],
+    description: Optional[str],
+    mappings: Optional[List[str]],
+    defaults: Optional[List[str]],
+    links: Optional[List[str]],
+    param_descriptions: Optional[List[str]],
     map_inputs: bool,
     map_outputs: bool,
     map_params: bool,
     link_all: bool,
-    keywords: List[str],
-    steps: List[str],
-    sources: List[str],
-    sinks: List[str],
+    keywords: Optional[List[str]],
+    steps: Optional[List[str]],
+    sources: Optional[List[str]],
+    sinks: Optional[List[str]],
     creators: Optional[List[Person]],
     activity_gateway: IActivityGateway,
     plan_gateway: IPlanGateway,
@@ -362,19 +402,19 @@ def compose_workflow(
 
     Args:
         name(str): Name of the new composed Plan.
-        description(str): Description for the Plan.
-        mappings(List[str]): Mappings between parameters of this and child Plans.
-        defaults(List[str]): Default values for parameters.
-        links(List[str]): Links between parameters of child Plans.
-        param_descriptions(List[str]): Descriptions of parameters.
+        description(Optional[str]): Description for the Plan.
+        mappings(Optional[List[str]]): Mappings between parameters of this and child Plans.
+        defaults(Optional[List[str]]): Default values for parameters.
+        links(Optional[List[str]]): Links between parameters of child Plans.
+        param_descriptions(Optional[List[str]]): Descriptions of parameters.
         map_inputs(bool): Whether or not to automatically expose child inputs.
         map_outputs(bool): Whether or not to automatically expose child outputs.
         map_params(bool): Whether or not to automatically expose child parameters.
         link_all(bool): Whether or not to automatically link child steps' parameters.
-        keywords(List[str]): Keywords for the Plan.
-        steps(List[str]): Child steps to include.
-        sources(List[str]): Starting files when automatically detecting child Plans.
-        sinks(List[str]): Ending files when automatically detecting child Plans.
+        keywords(Optional[List[str]]): Keywords for the Plan.
+        steps(Optional[List[str]]): Child steps to include.
+        sources(Optional[List[str]]): Starting files when automatically detecting child Plans.
+        sinks(Optional[List[str]]): Ending files when automatically detecting child Plans.
         creators(Optional[List[Person]]): Creator(s) of the composite plan.
         activity_gateway(IActivityGateway): Injected activity gateway.
         plan_gateway(IPlanGateway): Injected plan gateway.
@@ -387,7 +427,7 @@ def compose_workflow(
     from renku.core.workflow.activity import get_activities_until_paths, sort_activities
 
     if plan_gateway.get_by_name(name):
-        raise errors.ParameterError(f"Duplicate workflow name: workflow '{name}' already exists.")
+        raise errors.DuplicateWorkflowNameError(f"Duplicate workflow name: Workflow '{name}' already exists.")
 
     child_workflows = []
     plan_activities = []
@@ -504,12 +544,16 @@ def compose_workflow(
 
 
 @inject.autoparams()
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def export_workflow(
     name_or_id,
     plan_gateway: IPlanGateway,
     format: str,
     output: Optional[Union[str, Path]],
-    values: Optional[str],
+    values: Optional[Dict[str, Any]],
+    basedir: Optional[str],
+    resolve_paths: Optional[bool],
+    nest_workflows: Optional[bool],
 ):
     """Export a workflow to a given format.
 
@@ -518,11 +562,24 @@ def export_workflow(
         plan_gateway(IPlanGateway): The injected Plan gateway.
         format(str): Format to export to.
         output(Optional[str]): Output path to store result at.
-        values(Optional[str]): Path to values file to apply before export.
+        values(Optional[Dict[str,Any]]): Parameter names and values to apply before export.
+        basedir(Optional[str]): The base path prepended to all paths in the exported workflow,
+            if None it defaults to the absolute path of the renku project.
+        resolve_paths(Optional[bool]): Resolve all symlinks and make paths absolute, defaults to True.
+        nest_workflows(Optional[bool]): Whether to try to nest all workflows into one specification and file or not,
+            defaults to False.
     Returns:
         The exported workflow as string.
     """
 
+    if resolve_paths is None:
+        resolve_paths = True
+
+    if basedir is None:
+        basedir_path = project_context.path
+    elif isinstance(basedir, str):
+        basedir_path = Path(basedir)
+
     workflow = plan_gateway.get_by_name_or_id(name_or_id)
 
     if is_plan_removed(workflow):
@@ -535,8 +592,7 @@ def export_workflow(
         output_path = cast(Path, output)
 
     if values:
-        parsed_values = safe_read_yaml(values)
-        rv = ValueResolver.get(workflow, parsed_values)
+        rv = ValueResolver.get(workflow, values)
         workflow = rv.apply()
         if rv.missing_parameters:
             communication.warn(
@@ -547,7 +603,14 @@ def export_workflow(
     from renku.core.plugin.workflow import workflow_converter
 
     converter = workflow_converter(format)
-    return converter(workflow=workflow, basedir=project_context.path, output=output_path, output_format=format)
+    return converter(
+        workflow=workflow,
+        basedir=basedir_path,
+        output=output_path,
+        output_format=format,
+        resolve_paths=resolve_paths,
+        nest_workflows=nest_workflows,
+    )
 
 
 def _lookup_paths_in_paths(lookup_paths: List[str], target_paths: List[str]):
@@ -587,6 +650,7 @@ def _lookup_paths_in_paths(lookup_paths: List[str], target_paths: List[str]):
 
 
 @inject.autoparams()
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def visualize_graph(
     sources: List[str],
     targets: List[str],
@@ -623,12 +687,13 @@ def visualize_graph(
     activities = get_activities_until_paths(
         paths=targets, sources=sources, revision=revision, activity_gateway=activity_gateway
     )
-    graph = create_activity_graph(list(activities), with_inputs_outputs=show_files)
+    graph = create_activity_graph(list(activities), with_inputs_outputs=show_files, with_hidden_dependencies=True)
     return ActivityGraphViewModel(graph)
 
 
 @inject.autoparams()
-def workflow_inputs(activity_gateway: IActivityGateway, paths: List[str] = None):
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
+def workflow_inputs(activity_gateway: IActivityGateway, paths: Optional[List[str]] = None):
     """Get inputs used by workflows.
 
     Args:
@@ -647,7 +712,8 @@ def workflow_inputs(activity_gateway: IActivityGateway, paths: List[str] = None)
 
 
 @inject.autoparams()
-def workflow_outputs(activity_gateway: IActivityGateway, paths: List[str] = None):
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
+def workflow_outputs(activity_gateway: IActivityGateway, paths: Optional[List[str]] = None):
     """Get inputs used by workflows.
 
     Args:
