@@ -20,6 +20,7 @@
 import os
 from collections import deque
 from pathlib import Path
+from typing import Deque, List, Tuple
 
 
 class DirectoryTree(dict):
@@ -74,7 +75,7 @@ class DirectoryTree(dict):
         filter = {
             os.path.sep,
         }
-        queue = deque()
+        queue: Deque[Tuple["DirectoryTree", List[str]]] = deque()
         queue.append((self, []))
 
         while queue:
