@@ -32,7 +32,13 @@ from renku.core import errors
 from renku.core.util.datetime8601 import local_now
 from renku.domain_model.provenance.agent import Person
 from renku.domain_model.provenance.annotation import Annotation
-from renku.domain_model.workflow.parameter import CommandInput, CommandOutput, CommandParameter, CommandParameterBase
+from renku.domain_model.workflow.parameter import (
+    CommandInput,
+    CommandOutput,
+    CommandParameter,
+    CommandParameterBase,
+    HiddenInput,
+)
 from renku.infrastructure.database import Persistent
 
 MAX_GENERATED_NAME_LENGTH = 25
@@ -41,6 +47,7 @@ MAX_GENERATED_NAME_LENGTH = 25
 class AbstractPlan(Persistent, ABC):
     """Abstract base class for all plans."""
 
+    date_created: datetime
     creators: List[Person] = list()
 
     def __init__(
@@ -49,7 +56,8 @@ class AbstractPlan(Persistent, ABC):
         description: Optional[str] = None,
         id: str,
         date_created: Optional[datetime] = None,
-        invalidated_at: Optional[datetime] = None,
+        date_modified: Optional[datetime] = None,
+        date_removed: Optional[datetime] = None,
         keywords: Optional[List[str]] = None,
         name: Optional[str] = None,
         project_id: Optional[str] = None,
@@ -59,7 +67,8 @@ class AbstractPlan(Persistent, ABC):
         self.description: Optional[str] = description
         self.id: str = id
         self.date_created: datetime = date_created or local_now()
-        self.invalidated_at: Optional[datetime] = invalidated_at
+        self.date_modified: datetime = date_modified or local_now()
+        self.date_removed: Optional[datetime] = date_removed
         self.keywords: List[str] = keywords or []
 
         if creators:
@@ -71,7 +80,7 @@ class AbstractPlan(Persistent, ABC):
         if name is None:
             self.name: str = self._get_default_name()
         else:
-            AbstractPlan.validate_name(name)
+            self.validate_name(name)
             self.name = name
 
     def __repr__(self):
@@ -80,10 +89,10 @@ class AbstractPlan(Persistent, ABC):
     @property
     def deleted(self) -> bool:
         """True if plan is deleted."""
-        return self.invalidated_at is not None
+        return self.date_removed is not None
 
     @staticmethod
-    def generate_id(uuid: Optional[str] = None) -> str:
+    def generate_id(*, uuid: Optional[str] = None, **_) -> str:
         """Generate an identifier for Plan."""
         uuid = uuid or uuid4().hex
         return f"/plans/{uuid}"
@@ -100,18 +109,15 @@ class AbstractPlan(Persistent, ABC):
     @staticmethod
     def validate_name(name: str):
         """Check a name for invalid characters."""
-        if not re.match("[a-zA-Z0-9-_]+", name):
-            raise errors.ParameterError(
-                f"Name {name} contains illegal characters. Only English letters, numbers, _ and - are allowed."
-            )
+        validate_plan_name(name=name)
 
-    def assign_new_id(self) -> str:
+    def assign_new_id(self, *, uuid: Optional[str] = None) -> str:
         """Assign a new UUID.
 
         This is required only when there is another plan which is exactly the same except the parameters' list.
         """
         current_uuid = self._extract_uuid()
-        new_uuid = uuid4().hex
+        new_uuid = uuid or uuid4().hex
         self.id = self.id.replace(current_uuid, new_uuid)
 
         # NOTE: We also need to re-assign the _p_oid since identifier has changed
@@ -147,14 +153,14 @@ class AbstractPlan(Persistent, ABC):
         """Return if an ``AbstractPlan`` has correct derived_from."""
         raise NotImplementedError()
 
-    def delete(self, *, when: datetime = local_now()):
+    def delete(self):
         """Mark a plan as deleted.
 
         NOTE: Don't call this function for deleting plans since it doesn't delete the whole plan derivatives chain. Use
         renku.core.workflow.plan::remove_plan instead.
         """
         self.unfreeze()
-        self.invalidated_at = when
+        self.date_removed = local_now()
         self.freeze()
 
 
@@ -163,36 +169,43 @@ class Plan(AbstractPlan):
 
     annotations: List[Annotation] = list()
 
+    hidden_inputs: List[HiddenInput] = list()
+    """Includes a list of dependencies that are defined by Renku and should be hidden from users."""
+
     def __init__(
         self,
         *,
-        parameters: Optional[List[CommandParameter]] = None,
+        annotations: Optional[List[Annotation]] = None,
         command: str,
+        creators: Optional[List[Person]] = None,
+        date_created: Optional[datetime] = None,
+        date_modified: Optional[datetime] = None,
+        derived_from: Optional[str] = None,
         description: Optional[str] = None,
+        hidden_inputs: List[HiddenInput] = None,
         id: str,
         inputs: Optional[List[CommandInput]] = None,
-        date_created: Optional[datetime] = None,
-        invalidated_at: Optional[datetime] = None,
+        date_removed: Optional[datetime] = None,
         keywords: Optional[List[str]] = None,
         name: Optional[str] = None,
-        derived_from: Optional[str] = None,
-        project_id: Optional[str] = None,
         outputs: Optional[List[CommandOutput]] = None,
+        parameters: Optional[List[CommandParameter]] = None,
+        project_id: Optional[str] = None,
         success_codes: Optional[List[int]] = None,
-        annotations: Optional[List[Annotation]] = None,
-        creators: Optional[List[Person]] = None,
     ):
+        self.annotations: List[Annotation] = annotations or []
         self.command: str = command
+        self.hidden_inputs: List[HiddenInput] = hidden_inputs or []
         self.inputs: List[CommandInput] = inputs or []
         self.outputs: List[CommandOutput] = outputs or []
         self.parameters: List[CommandParameter] = parameters or []
         self.success_codes: List[int] = success_codes or []
-        self.annotations: List[Annotation] = annotations or []
         super().__init__(
             id=id,
             description=description,
             date_created=date_created,
-            invalidated_at=invalidated_at,
+            date_modified=date_modified,
+            date_removed=date_removed,
             keywords=keywords,
             name=name,
             project_id=project_id,
@@ -201,16 +214,7 @@ class Plan(AbstractPlan):
         )
 
         # NOTE: Validate plan
-        all_names = [p.name for p in itertools.chain(self.inputs, self.outputs, self.parameters)]
-        seen: Set[str] = set()
-
-        duplicates: List[str] = []
-        for n in all_names:
-            if n in seen:
-                duplicates.append(n)
-            else:
-                seen.add(n)
-
+        duplicates = get_duplicate_arguments_names(plan=self)
         if duplicates:
             duplicates_string = ", ".join(duplicates)
             raise errors.ParameterError(f"Duplicate input, output or parameter names found: {duplicates_string}")
@@ -220,30 +224,31 @@ class Plan(AbstractPlan):
         """Comma-separated list of keywords associated with workflow."""
         return ", ".join(self.keywords)
 
-    def is_similar_to(self, other: "Plan") -> bool:
-        """Return true if plan has the same inputs/outputs/arguments as another plan."""
+    def is_equal_to(self, other: "Plan") -> bool:
+        """Return true if plan hasn't changed from the other plan."""
 
-        def get_input_patterns(plan: Plan):
-            return {e.default_value for e in plan.inputs}
+        def are_equal_with_order(values, other_values):
+            return len(values) == len(other_values) and all(s.is_equal_to(o) for s, o in zip(values, other_values))
 
-        def get_output_patterns(plan: Plan):
-            return {e.default_value for e in plan.outputs}
+        def are_equal(values, other_values):
+            return len(values) == len(other_values) and set(values) == set(other_values)
 
-        def get_parameters(plan: Plan):
-            return {(a.position, a.prefix, a.default_value) for a in plan.parameters}
-
-        # TODO: Check order of inputs/outputs/parameters as well after sorting by position
+        # TODO: Include ``annotations`` if it is added to the workflow definition file
         return (
-            self.command == other.command
-            and set(self.success_codes) == set(other.success_codes)
-            and get_input_patterns(self) == get_input_patterns(other)
-            and get_output_patterns(self) == get_output_patterns(other)
-            and get_parameters(self) == get_parameters(other)
+            self.name == other.name
+            and self.description == other.description
+            and self.project_id == other.project_id
+            and self.command == other.command
+            and are_equal(self.success_codes, other.success_codes)
+            and are_equal(self.keywords, other.keywords)
+            and are_equal(self.creators, other.creators)
+            and are_equal_with_order(self.inputs, other.inputs)
+            and are_equal_with_order(self.outputs, other.outputs)
+            and are_equal_with_order(self.parameters, other.parameters)
         )
 
     def resolve_mapping_path(self, mapping_path: str) -> Tuple[CommandParameterBase, "Plan"]:
         """Resolve a mapping path to its reference parameter."""
-
         parts = mapping_path.split(".", maxsplit=1)
 
         if len(parts) > 1:
@@ -289,18 +294,18 @@ class Plan(AbstractPlan):
             (p for p in self.inputs + self.outputs + self.parameters if parameter_id == p.id), None  # type: ignore
         )
 
-    def find_parameter_workflow(self, parameter: CommandParameterBase) -> Optional[AbstractPlan]:
+    def find_parameter_workflow(self, parameter: CommandParameterBase) -> Optional["Plan"]:
         """Return the workflow a parameter belongs to."""
         if self.find_parameter(parameter):
             return self
         return None
 
-    def assign_new_id(self):
+    def assign_new_id(self, *, uuid: Optional[str] = None):
         """Assign a new UUID.
 
         This is required only when there is another plan which is exactly the same except the parameters' list.
         """
-        new_uuid = super().assign_new_id()
+        new_uuid = super().assign_new_id(uuid=uuid)
         current_uuid = self._extract_uuid()
         if hasattr(self, "parameters"):
             self.parameters = copy.deepcopy(self.parameters)
@@ -329,14 +334,14 @@ class Plan(AbstractPlan):
         """Return if an ``Plan`` has correct derived_from."""
         return self.derived_from is not None and self.id != self.derived_from
 
-    def to_argv(self, with_streams: bool = False) -> List[Any]:
+    def to_argv(self, with_streams: bool = False, quote_string: bool = True) -> List[Any]:
         """Convert a Plan into argv list."""
         arguments = itertools.chain(self.inputs, self.outputs, self.parameters)
         filtered_arguments = filter(lambda a: a.position is not None and not getattr(a, "mapped_to", None), arguments)
         arguments = sorted(filtered_arguments, key=lambda a: a.position)  # type: ignore
 
         argv = self.command.split(" ") if self.command else []
-        argv.extend(e for a in arguments for e in a.to_argv())
+        argv.extend(e for a in arguments for e in a.to_argv(quote_string=quote_string))
 
         if with_streams:
             arguments = itertools.chain(self.inputs, self.outputs, self.parameters)
@@ -390,3 +395,26 @@ class PlanDetailsJson(marshmallow.Schema):
     description = marshmallow.fields.String()
     keywords = marshmallow.fields.List(marshmallow.fields.String())
     id = marshmallow.fields.String()
+
+
+def get_duplicate_arguments_names(plan: Plan) -> List[str]:
+    """Return a list of duplicate inputs/outputs/parameters names in a plan."""
+    all_names = [p.name for p in itertools.chain(plan.inputs, plan.outputs, plan.parameters) if p.name]
+    seen: Set[str] = set()
+
+    duplicates: List[str] = []
+    for n in all_names:
+        if n in seen:
+            duplicates.append(n)
+        else:
+            seen.add(n)
+
+    return duplicates
+
+
+def validate_plan_name(name: str, extra_valid_characters: str = "_-"):
+    """Check a name for invalid characters."""
+    if not re.match(f"^[a-zA-Z0-9][a-zA-Z0-9{extra_valid_characters}]+$", name):
+        raise errors.ParameterError(
+            f"Name '{name}' contains illegal characters. Only English letters, numbers, _ and - are allowed."
+        )
