@@ -351,16 +351,25 @@ class Database:
 
         return object
 
-    def get_from_path(self, path: str, absolute: bool = False) -> persistent.Persistent:
+    def get_from_path(
+        self, path: str, absolute: bool = False, override_type: Optional[str] = None
+    ) -> persistent.Persistent:
         """Load a database object from a path.
 
         Args:
             path(str): Path of the database object.
-            absolute(bool): Whether the path is absolute or a filename inside the database (Default value: False).
+            absolute(bool): Whether the path is absolute or a filename inside the database (Default value = False).
+            override_type(Optional[str]): load object as a different type than what is set inside `renku_data_type`
+                (Default value = None).
         Returns:
             persistent.Persistent: The object.
         """
         data = self._storage.load(filename=path, absolute=absolute)
+        if override_type is not None:
+            if "@renku_data_type" not in data:
+                raise errors.IncompatibleParametersError("Cannot override type on found data.")
+
+            data["@renku_data_type"] = override_type
         object = self._reader.deserialize(data)
         object._p_changed = 0
         object._p_serial = PERSISTED
@@ -779,12 +788,12 @@ class Storage:
                 self.path.mkdir(parents=True, exist_ok=True)
 
         if compress:
-            with open(path, "wb") as f, self.zstd_compressor.stream_writer(f) as compressor:
+            with open(path, "wb") as fb, self.zstd_compressor.stream_writer(fb) as compressor:
                 with io.TextIOWrapper(compressor) as out:
                     json.dump(data, out, ensure_ascii=False)
         else:
-            with open(path, "wt") as f:  # type: ignore
-                json.dump(data, f, ensure_ascii=False, sort_keys=True, indent=2)  # type: ignore
+            with open(path, "wt") as ft:
+                json.dump(data, ft, ensure_ascii=False, sort_keys=True, indent=2)
 
     def load(self, filename: str, absolute: bool = False):
         """Load data for object with object id oid.
@@ -1026,6 +1035,9 @@ class ObjectReader:
 
             cls = self._get_class(object_type)
 
+            if cls is None:
+                raise TypeError(f"Couldn't find class '{object_type}'")
+
             if issubclass(cls, datetime.datetime):
                 assert create
                 data = data["@renku_data_value"]
@@ -1065,7 +1077,7 @@ class ObjectReader:
 
             if issubclass(cls, persistent.Persistent):
                 new_object = cls.__new__(cls)
-                new_object._p_oid = oid
+                new_object._p_oid = oid  # type: ignore[attr-defined]
                 self.set_ghost_state(new_object, data)
             elif issubclass(cls, Enum):
                 # NOTE: Enum replaces __new__ on classes with its own versions that validates entries
