@@ -84,7 +84,7 @@ class Plan:
         return cls(
             command=plan.command,
             date_created=plan.date_created,
-            deleted=plan.invalidated_at is not None,
+            deleted=plan.date_removed is not None,
             description=plan.description,
             id=plan.id,
             inputs=[Input.from_parameter(i) for i in plan.inputs],
@@ -160,7 +160,7 @@ class CompositePlan:
         """
         return cls(
             date_created=composite_plan.date_created,
-            deleted=composite_plan.invalidated_at is not None,
+            deleted=composite_plan.date_removed is not None,
             description=composite_plan.description,
             id=composite_plan.id,
             keywords=composite_plan.keywords,
